import { PlusOutlined } from "@ant-design/icons"
import ProTable, { ActionType } from "@ant-design/pro-table";
import { Button } from "antd"
import React, { useRef, useState } from "react"
import tableConfig from "./tableConfig";
import { useAjax } from "@/Hook/useAjax";
import { getBackPolicyListApi } from "@/services/iaaSystem/backPolicy";
import ModalBackPolicy from "./modalBackPolicy";

/**
 * 回传策略
 * @returns 
 */
const BackPolicy: React.FC = () => {

    /***************************************/
    const actionRef = useRef<ActionType>();
    const [visible, setVisible] = useState<boolean>(false)
    const [initialValues, setInitialValues] = useState<any>()


    const getFolderList = useAjax((params) => getBackPolicyListApi(params), { type: 'table' })
    /***************************************/

    /**
     * 修改
     * @param data 
     */
    const handleEdit = (data: any) => {
        console.log(data)
        setInitialValues(data)
        setVisible(true)
    }

    return <>
        <ProTable<any>
            columns={tableConfig(handleEdit)}
            actionRef={actionRef}
            cardBordered
            request={async (params, sort, filter) => {
                console.log(sort, filter);
                return await getFolderList.run(params)
            }}
            editable={{
                type: 'multiple',
            }}
            rowKey="id"
            search={{
                labelWidth: 'auto',
            }}
            headerTitle={<strong>回传策略</strong>}
            toolBarRender={() => [
                <Button type="primary" onClick={() => {
                    setVisible(true)
                }}>
                    <PlusOutlined />
                    新建
                </Button>
            ]}
        />

        {/* 新增修改 */}
        {visible && <ModalBackPolicy 
            visible={visible}
            initialValues={initialValues}
            onChange={() => {
                setVisible(false)
                setInitialValues(undefined)
                actionRef.current?.reload()
            }}
            onClose={() => {
                setVisible(false)
                setInitialValues(undefined)
            }}
        />}
    </>
}

export default BackPolicy